@@ -21,7 +21,7 @@ def headblur(clip,fx,fy,r_zone,r_blur=None):
     offscreen.
     """
     
-    if r_blur==None: r_blur = 2*r_zone/3
+    if r_blur is None: r_blur = 2*r_zone/3
     
     def fl(gf,t):
         
