@@ -36,7 +36,7 @@ class SubtitlesClip(VideoClip):
 
     def __init__(self, subtitles, make_textclip=None):
         
-        VideoClip.__init__(self)
+        VideoClip.__init__(self, has_constant_size=False)
 
         if isinstance( subtitles, str):
             subtitles = file_to_subtitles(subtitles)
@@ -57,6 +57,9 @@ class SubtitlesClip(VideoClip):
         self.end=self.duration
         
         def add_textclip_if_none(t):
+            """ Will generate a textclip if it hasn't been generated asked
+            to generate it yet. If there is no subtitle to show at t, return
+            false. """
             sub =[((ta,tb),txt) for ((ta,tb),txt) in self.textclips.keys()
                    if (ta<=t<tb)]
             if sub == []:
@@ -67,6 +70,7 @@ class SubtitlesClip(VideoClip):
             sub = sub[0]
             if sub not in self.textclips.keys():
                 self.textclips[sub] = self.make_textclip(sub[1])
+
             return sub
 
         def make_frame(t):
@@ -80,7 +84,8 @@ class SubtitlesClip(VideoClip):
                     else np.array([[0]]))
         
         self.make_frame = make_frame
-        self.mask = VideoClip(make_mask_frame, ismask=True)
+        hasmask = (self.make_textclip('T').mask is not None)
+        self.mask = (VideoClip(make_mask_frame, ismask=True) if hasmask else None)
 
     def in_subclip(self, t_start= None, t_end= None):
         """ Returns a sequence of [(t1,t2), txt] covering all the given subclip
